@@ -1,7 +1,7 @@
 #coding=utf-8
 # -*- coding:utf-8 -*-
 
-from ..util import client,config, formater, ossclient, list2table, result_cache, sys_config
+from ..util import client,config, formater, oss_client, list2table, result_cache, sys_config
 from terminal import bold, magenta, gray, blue, green,red, yellow, confirm
 import json
 import os
@@ -15,11 +15,7 @@ DEFAULT_CLUSTER = "img=%s:type=%s" % (IMG_ID,INS_TYPE)
 
 def submit(cmd, cluster=DEFAULT_CLUSTER, timeout=172800, nodes=1, pack=None, env=None, mount=None):
 
-    pre_oss_path = config.getConfigs(config.COMMON,['osspath']).get('osspath')
-    if not pre_oss_path:
-        raise Exception('osspath is unset, type: "%s config -h" for more help' % CMD)
-
-    pre_oss_path = '%s/' % pre_oss_path.rstrip('/')
+    pre_oss_path = config.get_oss_path()
 
     job_desc = gen_job_desc()
 
@@ -207,5 +203,5 @@ def build_tar_and_upload(folder_path, oss_path):
 
     # upload
     print('Upload: %s ==> %s' % (dist, oss_path))
-    ossclient.upload_file_to_oss(oss_path, dist)
+    oss_client.upload_file( dist, oss_path)
 
