@@ -4,11 +4,11 @@ NAME = 'batchcompute-cli'
 COMMAND = 'batchcompute|bcs'
 CMD = 'bcs'
 
-IMG_ID = 'm-287zklx8l'
+IMG_ID = 'm-28s58a5qq'
 INS_TYPE='ecs.s3.large'
 LOCALE_SUPPORTED = ['en','zh','zh_CN']
 
-VERSION = '1.0.1'
+VERSION = '1.1.3'
 
 
 import sys
