@@ -1,5 +1,6 @@
 from ..const import *
 
+
 def getJSON():
     return {
         "login": {
@@ -28,7 +29,7 @@ def getJSON():
                 'state': 'state filter for listing jobs, scope: [Running|Stopped|Waiting|Finished|Failed]',
                 "id": 'jobId filter for listing jobs',
                 'name': 'jobName filter for listing jobs',
-                'description':'show description of a job'
+                'description': 'show description of a job'
             }
         },
         'log': {
@@ -39,9 +40,9 @@ def getJSON():
         },
         'create_cluster': {
             'description': 'create cluster',
-            'option':{
+            'option': {
                 'imageId': "required, ECS Image Id",
-                'groups':  "optional, groupInfo, format: <groupName>[:type=<instanceType>][:nodes=<instanceCount>], default:group1",
+                'groups': "optional, groupInfo, format: <groupName>[:type=<instanceType>][:nodes=<instanceCount>], default:group1",
                 'description': "optional, description, string",
                 'userDatas': "optional, user data, k=v pairs"
             }
@@ -49,44 +50,44 @@ def getJSON():
         'delete_cluster': {
             'description': 'delete cluster, multi-supported',
             'option': {
-                'yes': "optional, delete in silence mode"
+                'yes': "optional, delete in silent mode"
             }
         },
         'update_cluster': {
             'description': 'update cluster, only support updating DesiredVMCount currently',
             'option': {
-                'yes': "optional, update in silence mode",
+                'yes': "optional, update in silent mode",
                 'nodes': "required, should be positive integer"
             }
         },
         'create_job': {
             'description': 'create job from description json or a json file path.',
-            'option':{
+            'option': {
                 'filePath': 'local job description json file path'
             }
         },
         'restart_job': {
-            'description':'restart jobs, multi-supported',
+            'description': 'restart jobs, multi-supported',
             'option': {
-                'yes':  "optional, restart jobs in silence mode"
+                'yes': "optional, restart jobs in silent mode"
             }
         },
         'stop_job': {
             'description': 'stop jobs, multi-supported',
             'option': {
-                'yes':  "optional, stop jobs in silence mode"
+                'yes': "optional, stop jobs in silent mode"
             }
         },
         'delete_job': {
             'description': 'delete jobs, multi-supported',
             'option': {
-                'yes':  "optional, delete jobs in silence mode"
+                'yes': "optional, delete jobs in silent mode"
             }
         },
         'update_job': {
             'description': 'update job, only support update priority currently',
             'option': {
-                'yes':  "optional, update in silence mode",
+                'yes': "optional, update in silent mode",
                 'priority': "required, should be in scope [1..1000]"
             }
         },
@@ -96,7 +97,8 @@ def getJSON():
                 'cluster': """optional, should be a cluster_id, or an auto_cluster string.
                                  default value is an auto_cluster string: img=%s:type=%s.
                                  you can use a exists cluster(type '%s c' for more cluster id),
-                                 or use auto cluster, format: img=<imageId>:type=<instanceType> (instanceType default: %s, type '%s it' for more instanceType). """ % (IMG_ID, INS_TYPE, CMD, INS_TYPE, CMD),
+                                 or use auto cluster, format: img=<imageId>:type=<instanceType> (instanceType default: %s, type '%s it' for more instanceType). """ % (
+                IMG_ID, INS_TYPE, CMD, INS_TYPE, CMD),
                 'pack': "pack the files in the program_folder into worker.tar.gz, and upload to oss, if you didn't set this option, no pack, no upload",
                 'timeout': "job would failed if it had expired, default: 172800(2 days)",
                 'nodes': "the number of machines you needed to run the program, default: 1",
@@ -104,5 +106,52 @@ def getJSON():
                 'mount': "mount a oss path to local file system, kv-pairs, multi-supported, format: <oss_path>:<dir_path>[,<oss_path2>:<div_path2>...], example: oss://bucket/key:/home/admin/ossdir "
 
             }
+        },
+        'project': {
+            'description': 'project commanders: init, create, build, submit, etc.',
+            'create': {
+                'description': 'create a job project',
+                'option': {
+                    'type': """optional, job project type, default: empty(python), scope: [empty|python|java|shell]""",
+                    'job': 'optional, create job project from an exists job_id'
+                }
+            },
+            'build': {
+                'description': 'build project, package src/ to worker.tar.gz.'
+
+            },
+            'update': {
+                'description': 'update job.json',
+                'option': {
+                    'cluster': """should be a cluster_id, or an auto_cluster string.
+                              default value is an auto_cluster string: img=%s:type=%s.
+                              you can use a exists cluster(type '%s c' for more cluster id),
+                              or use auto cluster, format: img=<imageId>:type=<instanceType> (instanceType default: %s, type '%s it' for more instanceType). """
+                }
+            },
+            'submit':{
+                'description': 'upload worker.tar.gz and create a job'
+            },
+            'status': {
+                'description': 'show project status.'
+            }
+        },
+        'oss': {
+            'description': 'oss commanders: upload, download, mkdir, ls, etc.',
+            'pwd': {
+                'description': 'show current osspath',
+            },
+            'upload': {
+                'description': 'upload file or directory to oss, support wildcards *',
+                'option': {
+                    'recursion': "upload directory and the entire subtree to oss"
+                }
+            },
+            'download': {
+                'description': 'download file or directory from oss',
+                'option': {
+                    'recursion': "download directory and the entire subtree from oss"
+                }
+            }
         }
     }
