@@ -5,6 +5,7 @@ except:
     import configparser as ConfigParser
 
 import os
+from .. import const
 
 cf = ConfigParser.ConfigParser()
 
@@ -64,3 +65,11 @@ def removeConfig(section, key):
             pass
     else:
         return False
+
+def get_oss_path():
+    pre_oss_path = getConfigs(COMMON,['osspath']).get('osspath')
+    if not pre_oss_path:
+        raise Exception('osspath is unset, type: "%s config -h" for more help' % const.CMD)
+
+    pre_oss_path = '%s/' % pre_oss_path.rstrip('/')
+    return pre_oss_path
