@@ -92,7 +92,7 @@ def format_date_in_arr(arr, cols):
                 m[k] = format_datetime(v)
                 m['%sFromNow' % k] = from_now(v)
             else:
-                m[k] = 'null'
+                m[k] = '-'
         t.append(m)
     return t
 
@@ -103,7 +103,7 @@ def format_datetime(dt):
     elif isinstance(dt, STRING):
         return format_date_str(dt)
     else:
-        return dt or 'null'
+        return dt or '-'
 
 def format_date_str(s):
     if not s:
